@@ -1,3 +1,4 @@
+use static_assertions::assert_not_impl_all;
 use std::ptr::NonNull;
 
 use crate::bind;
@@ -10,6 +11,8 @@ pub struct GameController {
     ptr: NonNull<bind::SDL_GameController>,
 }
 
+assert_not_impl_all!(GameController: Send, Sync);
+
 pub struct GameControllerSet {
     controls: Vec<GameController>,
 }
