@@ -1,11 +1,14 @@
+use static_assertions::assert_not_impl_all;
 use std::marker::PhantomData;
 
 use crate::{bind, Sdl};
 
 pub struct Timer<'sdl> {
-    _phantom: PhantomData<&'sdl ()>,
+    _phantom: PhantomData<&'sdl Sdl>,
 }
 
+assert_not_impl_all!(Timer: Send, Sync);
+
 impl<'sdl> Timer<'sdl> {
     pub fn new(_: &'sdl Sdl) -> Self {
         Self {
