@@ -1,3 +1,4 @@
+use static_assertions::assert_not_impl_all;
 use std::mem::MaybeUninit;
 use std::ptr::NonNull;
 
@@ -21,6 +22,8 @@ pub struct Renderer<'window> {
     window: &'window Window<'window>,
 }
 
+assert_not_impl_all!(Renderer: Send, Sync);
+
 impl<'window> Renderer<'window> {
     pub fn new(window: &'window Window) -> Self {
         let raw = unsafe { bind::SDL_CreateRenderer(window.as_ptr(), -1, 0) };
@@ -35,7 +38,7 @@ impl<'window> Renderer<'window> {
     }
 
     pub fn window(&self) -> &Window {
-        &self.window
+        self.window
     }
 
     pub fn output_size(&self) -> Size {
