@@ -1,3 +1,4 @@
+use static_assertions::assert_not_impl_all;
 use std::marker::PhantomData;
 use std::ptr::NonNull;
 
@@ -43,6 +44,8 @@ pub struct Texture<'renderer> {
     _phantom: PhantomData<&'renderer ()>,
 }
 
+assert_not_impl_all!(Texture: Send, Sync);
+
 impl<'renderer> Texture<'renderer> {
     pub fn new(renderer: &'renderer Renderer<'renderer>, access: TextureAccess) -> Result<Self> {
         use super::window::ConfigExt;
